@@ -3,8 +3,10 @@ from .endpoint import Endpoint  # noqa
 from .file import File  # noqa
 from .mount import Mount  # noqa
 from .parameter import Parameter  # noqa
+from .pipelines.deployment_node import DeploymentNode  # noqa
 from .pipelines.edge import Edge  # noqa
 from .pipelines.execution_node import ExecutionNode  # noqa
 from .pipelines.node import Node  # noqa
 from .pipelines.pipeline import Pipeline  # noqa
+from .pipelines.task_node import TaskNode  # noqa
 from .step import Step  # noqa
