@@ -1,10 +1,12 @@
-from typing import Dict, List, Optional
+from typing import Any, List, Mapping, Optional
 
 from .parameter import Parameter
 
 
 class ParameterMap:
-    def __init__(self, *, parameters: Dict[str, Parameter], values) -> None:
+    """Container for an execution's parameters and the values assigned."""
+
+    def __init__(self, *, parameters: Mapping[str, Parameter], values: Mapping[str, Any]) -> None:
         self.parameters = parameters
         self.values = values
 
@@ -13,7 +15,6 @@ class ParameterMap:
         Build the CLI command line from the parameter values.
 
         :return: list of CLI strings -- not escaped!
-        :rtype: list[str]
         """
         param_bits = []
         for name in self.parameters:
@@ -24,16 +25,3 @@ class ParameterMap:
         param = self.parameters[name]
         value = self.values.get(param.name)
         return param.format_cli(value)
-
-
-class LegacyParameterMap:
-    def __init__(self, parameters_list: List[str]) -> None:
-        self.parameters_list = parameters_list
-        self.parameters = {}
-        self.values = {}
-
-    def build_parameters(self) -> List[str]:
-        return self.parameters_list[:]
-
-    def build_parameter_by_name(self, name):  # pragma: no cover
-        return None
