@@ -1,23 +1,30 @@
+from typing import List, Optional
+
+from ...lint import LintResult
 from .node import Node
+from .node_action import NodeAction
 
 
 class ExecutionNode(Node):
+    """Represents an execution node within a pipeline definition."""
+
     type = 'execution'
 
     def __init__(
         self,
         *,
-        name,
-        step,
-        override=None
+        name: str,
+        step: str,
+        actions: Optional[List[NodeAction]] = None,
+        override: dict = None
     ) -> None:
+        super().__init__(name=name, actions=actions)
         if override is None:
             override = {}
-        self.name = name
         self.step = step
         self.override = override
 
-    def lint(self, lint_result, context: dict) -> None:
+    def lint(self, lint_result: LintResult, context: dict) -> None:
         super().lint(lint_result, context)
         config = context['config']
         pipeline = context['pipeline']
